"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.delete_d_source_response_all_of import DeleteDSourceResponseAllOf
from delphix.api.gateway.model.engine import Engine
from delphix.api.gateway.model.job import Job
from delphix.api.gateway.model.job_task import JobTask
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.virtualization_task import VirtualizationTask
globals()['DeleteDSourceResponseAllOf'] = DeleteDSourceResponseAllOf
globals()['Engine'] = Engine
globals()['Job'] = Job
globals()['JobTask'] = JobTask
globals()['Tag'] = Tag
globals()['VirtualizationTask'] = VirtualizationTask
from delphix.api.gateway.model.delete_d_source_response import DeleteDSourceResponse


class TestDeleteDSourceResponse(unittest.TestCase):
    """DeleteDSourceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeleteDSourceResponse(self):
        """Test DeleteDSourceResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeleteDSourceResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
