"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.data_risk_data import DataRiskData
from delphix.api.gateway.model.data_risk_report_totals import DataRiskReportTotals
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
globals()['DataRiskData'] = DataRiskData
globals()['DataRiskReportTotals'] = DataRiskReportTotals
globals()['PaginatedResponseMetadata'] = PaginatedResponseMetadata
from delphix.api.gateway.model.search_data_risk_report_response import SearchDataRiskReportResponse


class TestSearchDataRiskReportResponse(unittest.TestCase):
    """SearchDataRiskReportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchDataRiskReportResponse(self):
        """Test SearchDataRiskReportResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchDataRiskReportResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
