"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.oracle_virtual_ip import OracleVirtualIP
from delphix.api.gateway.model.ssh_verification_strategy import SSHVerificationStrategy
globals()['OracleVirtualIP'] = OracleVirtualIP
globals()['SSHVerificationStrategy'] = SSHVerificationStrategy
from delphix.api.gateway.model.host_update_parameters import HostUpdateParameters


class TestHostUpdateParameters(unittest.TestCase):
    """HostUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHostUpdateParameters(self):
        """Test HostUpdateParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HostUpdateParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
