"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.algorithms_api import AlgorithmsApi  # noqa: E501


class TestAlgorithmsApi(unittest.TestCase):
    """AlgorithmsApi unit test stubs"""

    def setUp(self):
        self.api = AlgorithmsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_algorithm_tags(self):
        """Test case for create_algorithm_tags

        Create tags for an Algorithm.  # noqa: E501
        """
        pass

    def test_delete_algorithm_tags(self):
        """Test case for delete_algorithm_tags

        Delete tags for an Algorithm.  # noqa: E501
        """
        pass

    def test_get_algorithm_by_id(self):
        """Test case for get_algorithm_by_id

        Get an algorithm by ID.  # noqa: E501
        """
        pass

    def test_get_algorithm_dependencies_by_id(self):
        """Test case for get_algorithm_dependencies_by_id

        Get dependencies of an algorithm by ID.  # noqa: E501
        """
        pass

    def test_get_algorithm_tags(self):
        """Test case for get_algorithm_tags

        Get tags for an Algorithm.  # noqa: E501
        """
        pass

    def test_get_algorithms(self):
        """Test case for get_algorithms

        Retrieve the list of algorithms.  # noqa: E501
        """
        pass

    def test_search_algorithm_dependencies(self):
        """Test case for search_algorithm_dependencies

        Search for algorithm dependencies.  # noqa: E501
        """
        pass

    def test_search_algorithms(self):
        """Test case for search_algorithms

        Search for algorithms.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
