"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.storage_summary_historical_data_point import StorageSummaryHistoricalDataPoint
from delphix.api.gateway.model.storage_summary_projected_data_point import StorageSummaryProjectedDataPoint
globals()['StorageSummaryHistoricalDataPoint'] = StorageSummaryHistoricalDataPoint
globals()['StorageSummaryProjectedDataPoint'] = StorageSummaryProjectedDataPoint
from delphix.api.gateway.model.historical_storage_summary_aggregate import HistoricalStorageSummaryAggregate


class TestHistoricalStorageSummaryAggregate(unittest.TestCase):
    """HistoricalStorageSummaryAggregate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHistoricalStorageSummaryAggregate(self):
        """Test HistoricalStorageSummaryAggregate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HistoricalStorageSummaryAggregate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
