"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.database_templates_api import DatabaseTemplatesApi  # noqa: E501


class TestDatabaseTemplatesApi(unittest.TestCase):
    """DatabaseTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = DatabaseTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_database_template(self):
        """Test case for create_database_template

        Create a database template.  # noqa: E501
        """
        pass

    def test_create_database_template_tags(self):
        """Test case for create_database_template_tags

        Create tags for a DatabaseTemplate.  # noqa: E501
        """
        pass

    def test_delete_database_template(self):
        """Test case for delete_database_template

        Delete a DatabaseTemplate by ID.  # noqa: E501
        """
        pass

    def test_delete_database_template_tag(self):
        """Test case for delete_database_template_tag

        Delete tags for a DatabaseTemplate.  # noqa: E501
        """
        pass

    def test_get_database_template_by_id(self):
        """Test case for get_database_template_by_id

        Retrieve a DatabaseTemplate by ID.  # noqa: E501
        """
        pass

    def test_get_database_template_tags(self):
        """Test case for get_database_template_tags

        Get tags for a DatabaseTemplate.  # noqa: E501
        """
        pass

    def test_get_database_templates(self):
        """Test case for get_database_templates

        Retrieve the list of database templates.  # noqa: E501
        """
        pass

    def test_import_database_templates(self):
        """Test case for import_database_templates

        Imports the database templates from an engine.  # noqa: E501
        """
        pass

    def test_search_database_templates(self):
        """Test case for search_database_templates

        Search DatabaseTemplates.  # noqa: E501
        """
        pass

    def test_undo_import_database_templates(self):
        """Test case for undo_import_database_templates

        Undo an import of DatabaseTemplates on an Engine.  # noqa: E501
        """
        pass

    def test_update_database_template(self):
        """Test case for update_database_template

        Updates a DatabaseTemplate by ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
