"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.masking_files_api import MaskingFilesApi  # noqa: E501


class TestMaskingFilesApi(unittest.TestCase):
    """MaskingFilesApi unit test stubs"""

    def setUp(self):
        self.api = MaskingFilesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_masking_file_tags(self):
        """Test case for create_masking_file_tags

        Create tags for a masking file.  # noqa: E501
        """
        pass

    def test_delete_masking_file_tags(self):
        """Test case for delete_masking_file_tags

        Delete tags for a masking file  # noqa: E501
        """
        pass

    def test_get_masking_file_by_id(self):
        """Test case for get_masking_file_by_id

        Get a masking file by ID or name.  # noqa: E501
        """
        pass

    def test_get_masking_file_consumers(self):
        """Test case for get_masking_file_consumers

        Get all consumers associated with this masking file  # noqa: E501
        """
        pass

    def test_get_masking_file_tags(self):
        """Test case for get_masking_file_tags

        Get tags for a masking file.  # noqa: E501
        """
        pass

    def test_get_masking_files(self):
        """Test case for get_masking_files

        Retrieve the list of masking file uploads.  # noqa: E501
        """
        pass

    def test_search_masking_file_consumers(self):
        """Test case for search_masking_file_consumers

        Search consumers of a masking file.  # noqa: E501
        """
        pass

    def test_search_masking_files(self):
        """Test case for search_masking_files

        Search for masking files.  # noqa: E501
        """
        pass

    def test_update_masking_file_upload_by_id(self):
        """Test case for update_masking_file_upload_by_id

        Update a masking file upload by id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
