"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.discovery_expressions_api import DiscoveryExpressionsApi  # noqa: E501


class TestDiscoveryExpressionsApi(unittest.TestCase):
    """DiscoveryExpressionsApi unit test stubs"""

    def setUp(self):
        self.api = DiscoveryExpressionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_discovery_expression_tags(self):
        """Test case for create_discovery_expression_tags

        Create tags for a discovery expression.  # noqa: E501
        """
        pass

    def test_delete_discovery_expression_tags(self):
        """Test case for delete_discovery_expression_tags

        Delete tags for a discovery expression.  # noqa: E501
        """
        pass

    def test_get_discovery_expression_by_id(self):
        """Test case for get_discovery_expression_by_id

        Get a discovery expression by ID.  # noqa: E501
        """
        pass

    def test_get_discovery_expression_tags(self):
        """Test case for get_discovery_expression_tags

        Get tags for a discovery expression.  # noqa: E501
        """
        pass

    def test_get_discovery_expressions(self):
        """Test case for get_discovery_expressions

        Retrieve discovery expressions.  # noqa: E501
        """
        pass

    def test_search_discovery_expressions(self):
        """Test case for search_discovery_expressions

        Search discovery expressions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
