"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_export_transfer_strategy_parameters import BaseExportTransferStrategyParameters
from delphix.api.gateway.model.in_place_export_parameters_all_of import InPlaceExportParametersAllOf
from delphix.api.gateway.model.oracle_asm_layout_parameters import OracleAsmLayoutParameters
globals()['BaseExportTransferStrategyParameters'] = BaseExportTransferStrategyParameters
globals()['InPlaceExportParametersAllOf'] = InPlaceExportParametersAllOf
globals()['OracleAsmLayoutParameters'] = OracleAsmLayoutParameters
from delphix.api.gateway.model.oracle_asm_in_place_export_parameters import OracleAsmInPlaceExportParameters


class TestOracleAsmInPlaceExportParameters(unittest.TestCase):
    """OracleAsmInPlaceExportParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOracleAsmInPlaceExportParameters(self):
        """Test OracleAsmInPlaceExportParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OracleAsmInPlaceExportParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
