"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.storage_usage_api import StorageUsageApi  # noqa: E501


class TestStorageUsageApi(unittest.TestCase):
    """StorageUsageApi unit test stubs"""

    def setUp(self):
        self.api = StorageUsageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_historical_storage_summary_aggregate(self):
        """Test case for get_historical_storage_summary_aggregate

        Returns the aggregated historical storage usage of all registered engines over time, optionally with a projection of future storage usage.  # noqa: E501
        """
        pass

    def test_get_historical_storage_summary_by_engine(self):
        """Test case for get_historical_storage_summary_by_engine

        Returns the historical storage usage by engine over time, optionally with a projection of future storage usage.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
