"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.latency_test_request import LatencyTestRequest
from delphix.api.gateway.model.network_latency_test_result_all_of import NetworkLatencyTestResultAllOf
from delphix.api.gateway.model.network_test_base_result import NetworkTestBaseResult
globals()['LatencyTestRequest'] = LatencyTestRequest
globals()['NetworkLatencyTestResultAllOf'] = NetworkLatencyTestResultAllOf
globals()['NetworkTestBaseResult'] = NetworkTestBaseResult
from delphix.api.gateway.model.network_latency_test_result import NetworkLatencyTestResult


class TestNetworkLatencyTestResult(unittest.TestCase):
    """NetworkLatencyTestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkLatencyTestResult(self):
        """Test NetworkLatencyTestResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkLatencyTestResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
