"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.classifiers_api import ClassifiersApi  # noqa: E501


class TestClassifiersApi(unittest.TestCase):
    """ClassifiersApi unit test stubs"""

    def setUp(self):
        self.api = ClassifiersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_classifier_tags(self):
        """Test case for create_classifier_tags

        Create tags for a classifier.  # noqa: E501
        """
        pass

    def test_delete_classifier_tags(self):
        """Test case for delete_classifier_tags

        Delete tags for a classifier.  # noqa: E501
        """
        pass

    def test_get_classifier_by_id(self):
        """Test case for get_classifier_by_id

        Get a classifier by ID.  # noqa: E501
        """
        pass

    def test_get_classifier_discovery_policies(self):
        """Test case for get_classifier_discovery_policies

        Get discovery policies for a classifier.  # noqa: E501
        """
        pass

    def test_get_classifier_tags(self):
        """Test case for get_classifier_tags

        Get tags for a classifier.  # noqa: E501
        """
        pass

    def test_get_classifiers(self):
        """Test case for get_classifiers

        Retrieve classifiers.  # noqa: E501
        """
        pass

    def test_search_classifier_discovery_policies(self):
        """Test case for search_classifier_discovery_policies

        Search discovery policies for a classifier.  # noqa: E501
        """
        pass

    def test_search_classifiers(self):
        """Test case for search_classifiers

        Search for classifiers.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
