"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.bookmarks_api import BookmarksApi  # noqa: E501


class TestBookmarksApi(unittest.TestCase):
    """BookmarksApi unit test stubs"""

    def setUp(self):
        self.api = BookmarksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bookmark(self):
        """Test case for create_bookmark

        Create a bookmark at the current time.  # noqa: E501
        """
        pass

    def test_create_bookmark_tags(self):
        """Test case for create_bookmark_tags

        Create tags for a Bookmark.  # noqa: E501
        """
        pass

    def test_delete_bookmark(self):
        """Test case for delete_bookmark

        Delete a bookmark.  # noqa: E501
        """
        pass

    def test_delete_bookmark_tags(self):
        """Test case for delete_bookmark_tags

        Delete tags for a Bookmark.  # noqa: E501
        """
        pass

    def test_get_bookmark_by_id(self):
        """Test case for get_bookmark_by_id

        Get a bookmark by ID.  # noqa: E501
        """
        pass

    def test_get_bookmark_tags(self):
        """Test case for get_bookmark_tags

        Get tags for a Bookmark.  # noqa: E501
        """
        pass

    def test_get_bookmarks(self):
        """Test case for get_bookmarks

        List all bookmarks.  # noqa: E501
        """
        pass

    def test_get_vdb_groups_by_bookmark(self):
        """Test case for get_vdb_groups_by_bookmark

        List VDB Groups compatible with this bookmark.  # noqa: E501
        """
        pass

    def test_import_engine_bookmarks(self):
        """Test case for import_engine_bookmarks

        Import engine bookmarks to DCT.  # noqa: E501
        """
        pass

    def test_search_bookmarks(self):
        """Test case for search_bookmarks

        Search for bookmarks.  # noqa: E501
        """
        pass

    def test_search_vdb_groups_by_bookmark(self):
        """Test case for search_vdb_groups_by_bookmark

        Search for VDB Groups compatible with this bookmark.  # noqa: E501
        """
        pass

    def test_update_bookmark(self):
        """Test case for update_bookmark

        Update a bookmark  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
