"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.delete_staging_cdb_response import DeleteStagingCDBResponse
from delphix.api.gateway.model.delete_staging_cdb_parameters import DeleteStagingCdbParameters
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.disable_cdb_parameters import DisableCDBParameters
from delphix.api.gateway.model.disable_staging_cdb_response import DisableStagingCDBResponse
from delphix.api.gateway.model.enable_cdb_parameters import EnableCDBParameters
from delphix.api.gateway.model.enable_staging_cdb_response import EnableStagingCDBResponse
from delphix.api.gateway.model.list_staging_cdbs_response import ListStagingCdbsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_staging_cdbs_response import SearchStagingCdbsResponse
from delphix.api.gateway.model.staging_cdb import StagingCdb
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse


class StagingCdbsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_staging_cdb_tags(
            self,
            staging_cdb_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_staging_cdb_tags(staging_cdb_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.
                tags_request (TagsRequest): Tags information for staging CDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_staging_cdb_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/tags',
                'operation_id': 'create_staging_cdb_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'tags_request',
                ],
                'required': [
                    'staging_cdb_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_staging_cdb_tags
        )

        def __delete_staging_cdb(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Delete a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_staging_cdb(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                delete_staging_cdb_parameters (DeleteStagingCdbParameters): The parameters to delete a staging CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteStagingCDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.delete_staging_cdb = _Endpoint(
            settings={
                'response_type': (DeleteStagingCDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/delete',
                'operation_id': 'delete_staging_cdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'delete_staging_cdb_parameters',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'delete_staging_cdb_parameters':
                        (DeleteStagingCdbParameters,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'delete_staging_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_staging_cdb
        )

        def __delete_staging_cdb_tags(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Delete tags for a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_staging_cdb_tags(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.delete_staging_cdb_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/tags/delete',
                'operation_id': 'delete_staging_cdb_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'delete_tag',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_staging_cdb_tags
        )

        def __disable_staging_cdb(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Disable a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.disable_staging_cdb(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                disable_cdb_parameters (DisableCDBParameters): The parameters to disable a staging CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DisableStagingCDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.disable_staging_cdb = _Endpoint(
            settings={
                'response_type': (DisableStagingCDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/disable',
                'operation_id': 'disable_staging_cdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'disable_cdb_parameters',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'disable_cdb_parameters':
                        (DisableCDBParameters,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'disable_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__disable_staging_cdb
        )

        def __enable_staging_cdb(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Enable a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.enable_staging_cdb(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                enable_cdb_parameters (EnableCDBParameters): The parameters to enable a staging CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EnableStagingCDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.enable_staging_cdb = _Endpoint(
            settings={
                'response_type': (EnableStagingCDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/enable',
                'operation_id': 'enable_staging_cdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                    'enable_cdb_parameters',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                    'enable_cdb_parameters':
                        (EnableCDBParameters,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                    'enable_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__enable_staging_cdb
        )

        def __get_staging_cdb_by_id(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Get a Staging CDB by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_staging_cdb_by_id(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StagingCdb
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.get_staging_cdb_by_id = _Endpoint(
            settings={
                'response_type': (StagingCdb,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}',
                'operation_id': 'get_staging_cdb_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_staging_cdb_by_id
        )

        def __get_staging_cdb_tags(
            self,
            staging_cdb_id,
            **kwargs
        ):
            """Get tags for a staging CDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_staging_cdb_tags(staging_cdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                staging_cdb_id (str): The Staging CDB ID.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['staging_cdb_id'] = \
                staging_cdb_id
            return self.call_with_http_info(**kwargs)

        self.get_staging_cdb_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/{stagingCdbId}/tags',
                'operation_id': 'get_staging_cdb_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'staging_cdb_id',
                ],
                'required': [
                    'staging_cdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'staging_cdb_id':
                        (str,),
                },
                'attribute_map': {
                    'staging_cdb_id': 'stagingCdbId',
                },
                'location_map': {
                    'staging_cdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_staging_cdb_tags
        )

        def __get_staging_cdbs(
            self,
            **kwargs
        ):
            """List all Staging CDBs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_staging_cdbs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListStagingCdbsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_staging_cdbs = _Endpoint(
            settings={
                'response_type': (ListStagingCdbsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs',
                'operation_id': 'get_staging_cdbs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "JDBC_CONNECTION_STRING": "jdbc_connection_string",
                        "-JDBC_CONNECTION_STRING": "-jdbc_connection_string",
                        "AGENT_ID": "agent_id",
                        "-AGENT_ID": "-agent_id",
                        "NAMESPACE_ID": "namespace_id",
                        "-NAMESPACE_ID": "-namespace_id",
                        "NAMESPACE_NAME": "namespace_name",
                        "-NAMESPACE_NAME": "-namespace_name",
                        "IS_REPLICA": "is_replica",
                        "-IS_REPLICA": "-is_replica",
                        "ENGINE_CONTAINER_REFERENCE": "engine_container_reference",
                        "-ENGINE_CONTAINER_REFERENCE": "-engine_container_reference",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "ENABLED": "enabled",
                        "-ENABLED": "-enabled",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "INSTANCE_NAME": "instance_name",
                        "-INSTANCE_NAME": "-instance_name",
                        "INSTANCE_NUMBER": "instance_number",
                        "-INSTANCE_NUMBER": "-instance_number",
                        "REPOSITORY_ID": "repository_id",
                        "-REPOSITORY_ID": "-repository_id",
                        "TDE_KEYSTORE_CONFIG_TYPE": "tde_keystore_config_type",
                        "-TDE_KEYSTORE_CONFIG_TYPE": "-tde_keystore_config_type",
                        "DATABASE_UNIQUE_NAME": "database_unique_name",
                        "-DATABASE_UNIQUE_NAME": "-database_unique_name",
                        "TDE_KMS_PKCS11_CONFIG_PATH": "tde_kms_pkcs11_config_path",
                        "-TDE_KMS_PKCS11_CONFIG_PATH": "-tde_kms_pkcs11_config_path",
                        "IS_TDE_KEYSTORE_PASSWORD_SET": "is_tde_keystore_password_set",
                        "-IS_TDE_KEYSTORE_PASSWORD_SET": "-is_tde_keystore_password_set",
                        "AUTO_STAGING_PUSH_RESTART": "auto_staging_push_restart",
                        "-AUTO_STAGING_PUSH_RESTART": "-auto_staging_push_restart",
                        "CONFIGURE_STAGING_DB_PARAMS": "configure_staging_db_params",
                        "-CONFIGURE_STAGING_DB_PARAMS": "-configure_staging_db_params",
                        "PHYSICAL_STANDBY": "physical_standby",
                        "-PHYSICAL_STANDBY": "-physical_standby",
                        "VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "validate_snapshot_by_opening_db_in_read_mode",
                        "-VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "-validate_snapshot_by_opening_db_in_read_mode",
                        "MOUNT_BASE": "mount_base",
                        "-MOUNT_BASE": "-mount_base",
                        "DATAFILE_MOUNT_PATH": "datafile_mount_path",
                        "-DATAFILE_MOUNT_PATH": "-datafile_mount_path",
                        "ARCHIVE_MOUNT_PATH": "archive_mount_path",
                        "-ARCHIVE_MOUNT_PATH": "-archive_mount_path",
                        "NFS_VERSION": "nfs_version",
                        "-NFS_VERSION": "-nfs_version",
                        "NFS_VERSION_REASON": "nfs_version_reason",
                        "-NFS_VERSION_REASON": "-nfs_version_reason",
                        "NFS_ENCRYPTION_ENABLED": "nfs_encryption_enabled",
                        "-NFS_ENCRYPTION_ENABLED": "-nfs_encryption_enabled"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_staging_cdbs
        )

        def __search_staging_cdbs(
            self,
            **kwargs
        ):
            """Search for Staging CDBs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_staging_cdbs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchStagingCdbsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_staging_cdbs = _Endpoint(
            settings={
                'response_type': (SearchStagingCdbsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/staging-cdbs/search',
                'operation_id': 'search_staging_cdbs',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "JDBC_CONNECTION_STRING": "jdbc_connection_string",
                        "-JDBC_CONNECTION_STRING": "-jdbc_connection_string",
                        "AGENT_ID": "agent_id",
                        "-AGENT_ID": "-agent_id",
                        "NAMESPACE_ID": "namespace_id",
                        "-NAMESPACE_ID": "-namespace_id",
                        "NAMESPACE_NAME": "namespace_name",
                        "-NAMESPACE_NAME": "-namespace_name",
                        "IS_REPLICA": "is_replica",
                        "-IS_REPLICA": "-is_replica",
                        "ENGINE_CONTAINER_REFERENCE": "engine_container_reference",
                        "-ENGINE_CONTAINER_REFERENCE": "-engine_container_reference",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "ENABLED": "enabled",
                        "-ENABLED": "-enabled",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "INSTANCE_NAME": "instance_name",
                        "-INSTANCE_NAME": "-instance_name",
                        "INSTANCE_NUMBER": "instance_number",
                        "-INSTANCE_NUMBER": "-instance_number",
                        "REPOSITORY_ID": "repository_id",
                        "-REPOSITORY_ID": "-repository_id",
                        "TDE_KEYSTORE_CONFIG_TYPE": "tde_keystore_config_type",
                        "-TDE_KEYSTORE_CONFIG_TYPE": "-tde_keystore_config_type",
                        "DATABASE_UNIQUE_NAME": "database_unique_name",
                        "-DATABASE_UNIQUE_NAME": "-database_unique_name",
                        "TDE_KMS_PKCS11_CONFIG_PATH": "tde_kms_pkcs11_config_path",
                        "-TDE_KMS_PKCS11_CONFIG_PATH": "-tde_kms_pkcs11_config_path",
                        "IS_TDE_KEYSTORE_PASSWORD_SET": "is_tde_keystore_password_set",
                        "-IS_TDE_KEYSTORE_PASSWORD_SET": "-is_tde_keystore_password_set",
                        "AUTO_STAGING_PUSH_RESTART": "auto_staging_push_restart",
                        "-AUTO_STAGING_PUSH_RESTART": "-auto_staging_push_restart",
                        "CONFIGURE_STAGING_DB_PARAMS": "configure_staging_db_params",
                        "-CONFIGURE_STAGING_DB_PARAMS": "-configure_staging_db_params",
                        "PHYSICAL_STANDBY": "physical_standby",
                        "-PHYSICAL_STANDBY": "-physical_standby",
                        "VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "validate_snapshot_by_opening_db_in_read_mode",
                        "-VALIDATE_SNAPSHOT_BY_OPENING_DB_IN_READ_MODE": "-validate_snapshot_by_opening_db_in_read_mode",
                        "MOUNT_BASE": "mount_base",
                        "-MOUNT_BASE": "-mount_base",
                        "DATAFILE_MOUNT_PATH": "datafile_mount_path",
                        "-DATAFILE_MOUNT_PATH": "-datafile_mount_path",
                        "ARCHIVE_MOUNT_PATH": "archive_mount_path",
                        "-ARCHIVE_MOUNT_PATH": "-archive_mount_path",
                        "NFS_VERSION": "nfs_version",
                        "-NFS_VERSION": "-nfs_version",
                        "NFS_VERSION_REASON": "nfs_version_reason",
                        "-NFS_VERSION_REASON": "-nfs_version_reason",
                        "NFS_ENCRYPTION_ENABLED": "nfs_encryption_enabled",
                        "-NFS_ENCRYPTION_ENABLED": "-nfs_encryption_enabled"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_staging_cdbs
        )
