"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.deletion_dependency_object import DeletionDependencyObject
from delphix.api.gateway.model.deletion_dependency_prerequisite_action import DeletionDependencyPrerequisiteAction
globals()['DeletionDependencyObject'] = DeletionDependencyObject
globals()['DeletionDependencyPrerequisiteAction'] = DeletionDependencyPrerequisiteAction
from delphix.api.gateway.model.deletion_dependencies_tree_response import DeletionDependenciesTreeResponse


class TestDeletionDependenciesTreeResponse(unittest.TestCase):
    """DeletionDependenciesTreeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeletionDependenciesTreeResponse(self):
        """Test DeletionDependenciesTreeResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeletionDependenciesTreeResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
