"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.hyperscale_objects_api import HyperscaleObjectsApi  # noqa: E501


class TestHyperscaleObjectsApi(unittest.TestCase):
    """HyperscaleObjectsApi unit test stubs"""

    def setUp(self):
        self.api = HyperscaleObjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_hyperscale_connector(self):
        """Test case for create_hyperscale_connector

        Create a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_create_hyperscale_connector_tags(self):
        """Test case for create_hyperscale_connector_tags

        Create tags for a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_create_hyperscale_dataset_tags(self):
        """Test case for create_hyperscale_dataset_tags

        Create tags for a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_create_hyperscale_mount_point(self):
        """Test case for create_hyperscale_mount_point

        Create a Hyperscale Mount Point  # noqa: E501
        """
        pass

    def test_delete_hyperscale_connector(self):
        """Test case for delete_hyperscale_connector

        Delete a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_connector_tags(self):
        """Test case for delete_hyperscale_connector_tags

        Delete tags for a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_dataset_tags(self):
        """Test case for delete_hyperscale_dataset_tags

        Delete tags for a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_mount_point(self):
        """Test case for delete_hyperscale_mount_point

        Delete a Hyperscale Mount Point.  # noqa: E501
        """
        pass

    def test_get_hyperscale_connector_by_id(self):
        """Test case for get_hyperscale_connector_by_id

        Get a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_get_hyperscale_connector_tags(self):
        """Test case for get_hyperscale_connector_tags

        Get tags for a Hyperscale Connector.  # noqa: E501
        """
        pass

    def test_get_hyperscale_connectors(self):
        """Test case for get_hyperscale_connectors

        Returns a list of Hyperscale Connectors.  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_by_id(self):
        """Test case for get_hyperscale_dataset_by_id

        Get a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_table_or_file_by_id(self):
        """Test case for get_hyperscale_dataset_table_or_file_by_id

        Get a Hyperscale Dataset table or file by ID.  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_tables_or_files(self):
        """Test case for get_hyperscale_dataset_tables_or_files

        Get the tables or files of a hyperscale dataset  # noqa: E501
        """
        pass

    def test_get_hyperscale_dataset_tags(self):
        """Test case for get_hyperscale_dataset_tags

        Get tags for a Hyperscale Dataset.  # noqa: E501
        """
        pass

    def test_get_hyperscale_datasets(self):
        """Test case for get_hyperscale_datasets

        Returns a list of Hyperscale Datasets.  # noqa: E501
        """
        pass

    def test_get_hyperscale_mount_point_by_id(self):
        """Test case for get_hyperscale_mount_point_by_id

        Get a Hyperscale Mount Points.  # noqa: E501
        """
        pass

    def test_get_hyperscale_mount_points(self):
        """Test case for get_hyperscale_mount_points

        Returns a list of Hyperscale Mount Points.  # noqa: E501
        """
        pass

    def test_search_hyperscale_connectors(self):
        """Test case for search_hyperscale_connectors

        Search for Hyperscale Connectors.  # noqa: E501
        """
        pass

    def test_search_hyperscale_dataset_tables_or_files(self):
        """Test case for search_hyperscale_dataset_tables_or_files

        Search the tables or files of a hyperscale dataset  # noqa: E501
        """
        pass

    def test_search_hyperscale_datasets(self):
        """Test case for search_hyperscale_datasets

        Search for Hyperscale Datasets.  # noqa: E501
        """
        pass

    def test_search_hyperscale_mount_points(self):
        """Test case for search_hyperscale_mount_points

        Search for Hyperscale Mount Points.  # noqa: E501
        """
        pass

    def test_update_hyperscale_connector_by_id(self):
        """Test case for update_hyperscale_connector_by_id

        Update a Hyperscale Connector by ID.  # noqa: E501
        """
        pass

    def test_update_hyperscale_dataset_by_id(self):
        """Test case for update_hyperscale_dataset_by_id

        Update a Hyperscale Dataset by ID.  # noqa: E501
        """
        pass

    def test_update_hyperscale_dataset_table_or_file_by_id(self):
        """Test case for update_hyperscale_dataset_table_or_file_by_id

        Update a Hyperscale Dataset table or file by ID.  # noqa: E501
        """
        pass

    def test_update_hyperscale_mount_point_by_id(self):
        """Test case for update_hyperscale_mount_point_by_id

        Update a Hyperscale Mount Point by ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
