"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.data_connections_api import DataConnectionsApi  # noqa: E501


class TestDataConnectionsApi(unittest.TestCase):
    """DataConnectionsApi unit test stubs"""

    def setUp(self):
        self.api = DataConnectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_data_connection_tags(self):
        """Test case for create_data_connection_tags

        Create tags for a data connection.  # noqa: E501
        """
        pass

    def test_delete_data_connection_tags(self):
        """Test case for delete_data_connection_tags

        Delete tags for a data connection.  # noqa: E501
        """
        pass

    def test_get_data_connection_by_id(self):
        """Test case for get_data_connection_by_id

        Get a data connection by id.  # noqa: E501
        """
        pass

    def test_get_data_connection_tags(self):
        """Test case for get_data_connection_tags

        Get tags for a data connection.  # noqa: E501
        """
        pass

    def test_get_data_connections(self):
        """Test case for get_data_connections

        Returns a list of data connections.  # noqa: E501
        """
        pass

    def test_get_sub_connections(self):
        """Test case for get_sub_connections

        Get sub-connections for a data connection.  # noqa: E501
        """
        pass

    def test_reassign_sub_connection(self):
        """Test case for reassign_sub_connection

        Reassign a SubConnection to another DataConnection.  # noqa: E501
        """
        pass

    def test_search_data_connections(self):
        """Test case for search_data_connections

        Search for data connections.  # noqa: E501
        """
        pass

    def test_search_sub_connections(self):
        """Test case for search_sub_connections

        Search for sub-connections for a data connections.  # noqa: E501
        """
        pass

    def test_update_data_connection(self):
        """Test case for update_data_connection

        Update a data connection.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
