"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.virtualization_faults_api import VirtualizationFaultsApi  # noqa: E501


class TestVirtualizationFaultsApi(unittest.TestCase):
    """VirtualizationFaultsApi unit test stubs"""

    def setUp(self):
        self.api = VirtualizationFaultsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_virtualization_faults_history(self):
        """Test case for get_virtualization_faults_history

        Fetch a list of all virtualization faults  # noqa: E501
        """
        pass

    def test_resolve_all_virtualization_faults(self):
        """Test case for resolve_all_virtualization_faults

        Marks all active faults of an engine that the user has permissions over as resolved.  # noqa: E501
        """
        pass

    def test_resolve_or_ignore_virtualization_faults(self):
        """Test case for resolve_or_ignore_virtualization_faults

        Marks selected faults as resolved or ignored.  # noqa: E501
        """
        pass

    def test_resolve_virtualization_fault(self):
        """Test case for resolve_virtualization_fault

        Marks the fault as resolved. The Delphix engine will attempt to automatically detect cases where the fault has been resolved; but this is not always possible and may only occur on periodic intervals. In these cases, the user can proactively mark the fault resolved. This does not change the underlying disposition of the fault - if the problem is still present the system may immediately diagnose the same problem again. This should only be used to notify the system of resolution after the underlying problem has been resolved.  # noqa: E501
        """
        pass

    def test_search_virtualization_faults_history(self):
        """Test case for search_virtualization_faults_history

        Search virtualization faults  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
