"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.database_table_metadata import DatabaseTableMetadata


class TestDatabaseTableMetadata(unittest.TestCase):
    """DatabaseTableMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDatabaseTableMetadata(self):
        """Test DatabaseTableMetadata"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DatabaseTableMetadata()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
