"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.data_layouts_api import DataLayoutsApi  # noqa: E501


class TestDataLayoutsApi(unittest.TestCase):
    """DataLayoutsApi unit test stubs"""

    def setUp(self):
        self.api = DataLayoutsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_convert_and_drop_bookmarks(self):
        """Test case for convert_and_drop_bookmarks

        Convert and drop engine bookmarks and vdb groups for the data-layout.  # noqa: E501
        """
        pass

    def test_create_data_layout_tags(self):
        """Test case for create_data_layout_tags

        Create tags for a data-layout.  # noqa: E501
        """
        pass

    def test_delete_data_layout_tags(self):
        """Test case for delete_data_layout_tags

        Delete tags for a data-layout.  # noqa: E501
        """
        pass

    def test_get_data_layout_by_id(self):
        """Test case for get_data_layout_by_id

        Get a data-layout by ID.  # noqa: E501
        """
        pass

    def test_get_data_layout_tags(self):
        """Test case for get_data_layout_tags

        Get tags for a data-layout.  # noqa: E501
        """
        pass

    def test_get_data_layouts(self):
        """Test case for get_data_layouts

        List all data-layout (Self-Service Container/Template).  # noqa: E501
        """
        pass

    def test_import_engine_accounts(self):
        """Test case for import_engine_accounts

        Import engine (self-service) accounts.  # noqa: E501
        """
        pass

    def test_search_data_layouts(self):
        """Test case for search_data_layouts

        Search for data-layouts.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
