"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.authorization_api import AuthorizationApi  # noqa: E501


class TestAuthorizationApi(unittest.TestCase):
    """AuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = AuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_access_group_account_ids(self):
        """Test case for add_access_group_account_ids

        Add account ids to an Access group  # noqa: E501
        """
        pass

    def test_add_access_group_account_tags(self):
        """Test case for add_access_group_account_tags

        Add account tags to an Access group  # noqa: E501
        """
        pass

    def test_add_access_group_scopes(self):
        """Test case for add_access_group_scopes

        Add scopes to an Access group  # noqa: E501
        """
        pass

    def test_add_always_allowed_permissions(self):
        """Test case for add_always_allowed_permissions

        Add always allowed permissions for given object type.  # noqa: E501
        """
        pass

    def test_add_objects_to_access_group_scope(self):
        """Test case for add_objects_to_access_group_scope

        Add objects to the access group scope.  # noqa: E501
        """
        pass

    def test_add_role_permissions(self):
        """Test case for add_role_permissions

        Add permissions to a role.  # noqa: E501
        """
        pass

    def test_add_role_ui_profiles(self):
        """Test case for add_role_ui_profiles

        Add UI profiles to a role.  # noqa: E501
        """
        pass

    def test_add_tags_to_scope(self):
        """Test case for add_tags_to_scope

        Add object tags to the access group scope.  # noqa: E501
        """
        pass

    def test_create_access_group(self):
        """Test case for create_access_group

        Create a new access group.  # noqa: E501
        """
        pass

    def test_create_role(self):
        """Test case for create_role

        Create custom role  # noqa: E501
        """
        pass

    def test_create_role_tags(self):
        """Test case for create_role_tags

        Create tags for a role.  # noqa: E501
        """
        pass

    def test_delete_access_group(self):
        """Test case for delete_access_group

        Delete an Access group.  # noqa: E501
        """
        pass

    def test_delete_access_group_scope_object_tags(self):
        """Test case for delete_access_group_scope_object_tags

        Remove tags from the access group scope.  # noqa: E501
        """
        pass

    def test_delete_access_group_scope_objects(self):
        """Test case for delete_access_group_scope_objects

        Remove objects from the access group scope.  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Delete role by ID.  # noqa: E501
        """
        pass

    def test_delete_role_tag(self):
        """Test case for delete_role_tag

        Delete tags for a Role.  # noqa: E501
        """
        pass

    def test_delete_role_ui_profiles(self):
        """Test case for delete_role_ui_profiles

        Delete UI profiles from a Role.  # noqa: E501
        """
        pass

    def test_get_access_group_by_id(self):
        """Test case for get_access_group_by_id

        Returns an Access group by ID.  # noqa: E501
        """
        pass

    def test_get_access_group_scope(self):
        """Test case for get_access_group_scope

        Get access group scope.  # noqa: E501
        """
        pass

    def test_get_access_groups(self):
        """Test case for get_access_groups

        List all access groups.  # noqa: E501
        """
        pass

    def test_get_all_object_permissions(self):
        """Test case for get_all_object_permissions

        Returns all of the possible permissions for all of the objects.  # noqa: E501
        """
        pass

    def test_get_object_permissions(self):
        """Test case for get_object_permissions

        Returns permissions for given object.  # noqa: E501
        """
        pass

    def test_get_role_by_id(self):
        """Test case for get_role_by_id

        Returns role by ID.  # noqa: E501
        """
        pass

    def test_get_role_tags(self):
        """Test case for get_role_tags

        Get tags for a Role.  # noqa: E501
        """
        pass

    def test_get_roles(self):
        """Test case for get_roles

        List all roles  # noqa: E501
        """
        pass

    def test_remove_access_group_account_id(self):
        """Test case for remove_access_group_account_id

        Remove the account from the access group.  # noqa: E501
        """
        pass

    def test_remove_access_group_account_tags(self):
        """Test case for remove_access_group_account_tags

        Remove account tags from an access group.  # noqa: E501
        """
        pass

    def test_remove_access_group_scope(self):
        """Test case for remove_access_group_scope

        Remove the scope from the Access group.  # noqa: E501
        """
        pass

    def test_remove_always_allowed_permissions(self):
        """Test case for remove_always_allowed_permissions

        Remove always allowed permissions for given object type.  # noqa: E501
        """
        pass

    def test_remove_role_permissions(self):
        """Test case for remove_role_permissions

        Remove permissions from a role.  # noqa: E501
        """
        pass

    def test_search_access_groups(self):
        """Test case for search_access_groups

        Search for access groups.  # noqa: E501
        """
        pass

    def test_search_roles(self):
        """Test case for search_roles

        Search for roles.  # noqa: E501
        """
        pass

    def test_update_access_group(self):
        """Test case for update_access_group

        Update an Access group.  # noqa: E501
        """
        pass

    def test_update_access_group_scope(self):
        """Test case for update_access_group_scope

        Update access group scope.  # noqa: E501
        """
        pass

    def test_update_role(self):
        """Test case for update_role

        Update a Role.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
