"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
from delphix.api.gateway.model.cluster_node_instance import ClusterNodeInstance
from delphix.api.gateway.model.config_settings_stg import ConfigSettingsStg
from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
from delphix.api.gateway.model.tag import Tag
globals()['AdditionalMountPoint'] = AdditionalMountPoint
globals()['ClusterNodeInstance'] = ClusterNodeInstance
globals()['ConfigSettingsStg'] = ConfigSettingsStg
globals()['OracleRacCustomEnvFile'] = OracleRacCustomEnvFile
globals()['OracleRacCustomEnvVar'] = OracleRacCustomEnvVar
globals()['OracleTdeKeystoreConfigTypeEnum'] = OracleTdeKeystoreConfigTypeEnum
globals()['Tag'] = Tag
from delphix.api.gateway.model.base_provision_vdb_parameters_all_of import BaseProvisionVDBParametersAllOf


class TestBaseProvisionVDBParametersAllOf(unittest.TestCase):
    """BaseProvisionVDBParametersAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBaseProvisionVDBParametersAllOf(self):
        """Test BaseProvisionVDBParametersAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = BaseProvisionVDBParametersAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
