"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.namespace_api import NamespaceApi  # noqa: E501


class TestNamespaceApi(unittest.TestCase):
    """NamespaceApi unit test stubs"""

    def setUp(self):
        self.api = NamespaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_commit_failover_namespace(self):
        """Test case for commit_failover_namespace

        Commits the failover of a given namespace and discards the failback state.  # noqa: E501
        """
        pass

    def test_delete_namespace(self):
        """Test case for delete_namespace

        Delete a Namespace.  # noqa: E501
        """
        pass

    def test_discard_namespace(self):
        """Test case for discard_namespace

        Discards any partial receive state for the given namespace.  # noqa: E501
        """
        pass

    def test_failback_namespace(self):
        """Test case for failback_namespace

        Initiates failback for the given namespace.  # noqa: E501
        """
        pass

    def test_failover_namespace(self):
        """Test case for failover_namespace

        Initiates failover for the given namespace.  # noqa: E501
        """
        pass

    def test_get_namespace_by_id(self):
        """Test case for get_namespace_by_id

        Get a namespace.  # noqa: E501
        """
        pass

    def test_list_namespaces(self):
        """Test case for list_namespaces

        List all namespaces.  # noqa: E501
        """
        pass

    def test_search_namespaces(self):
        """Test case for search_namespaces

        Search Namespaces.  # noqa: E501
        """
        pass

    def test_update_namespace(self):
        """Test case for update_namespace

        Update a Namespace.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
