"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.discovery_policies_api import DiscoveryPoliciesApi  # noqa: E501


class TestDiscoveryPoliciesApi(unittest.TestCase):
    """DiscoveryPoliciesApi unit test stubs"""

    def setUp(self):
        self.api = DiscoveryPoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_discovery_policy_tags(self):
        """Test case for create_discovery_policy_tags

        Create tags for a discovery policy.  # noqa: E501
        """
        pass

    def test_delete_discovery_policy_tags(self):
        """Test case for delete_discovery_policy_tags

        Delete tags for a discovery policy.  # noqa: E501
        """
        pass

    def test_get_discovery_policies(self):
        """Test case for get_discovery_policies

        Retrieve discovery policies.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_by_id(self):
        """Test case for get_discovery_policy_by_id

        Get a discovery policy by ID.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_classifiers(self):
        """Test case for get_discovery_policy_classifiers

        Get classifiers for a discovery policy.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_expressions(self):
        """Test case for get_discovery_policy_expressions

        Get discovery expressions for a discovery policy.  # noqa: E501
        """
        pass

    def test_get_discovery_policy_tags(self):
        """Test case for get_discovery_policy_tags

        Get tags for a discovery policy.  # noqa: E501
        """
        pass

    def test_search_discovery_policies(self):
        """Test case for search_discovery_policies

        Search for discovery policies.  # noqa: E501
        """
        pass

    def test_search_discovery_policy_classifiers(self):
        """Test case for search_discovery_policy_classifiers

        Search for classifiers of a discovery policy.  # noqa: E501
        """
        pass

    def test_search_discovery_policy_expressions(self):
        """Test case for search_discovery_policy_expressions

        Search for discovery expressions of a discovery policy.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
