"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.d_sources_api import DSourcesApi  # noqa: E501


class TestDSourcesApi(unittest.TestCase):
    """DSourcesApi unit test stubs"""

    def setUp(self):
        self.api = DSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_mssql_database(self):
        """Test case for attach_mssql_database

        Attaches a MSSql source to a previously detached dsource.  # noqa: E501
        """
        pass

    def test_attach_mssql_staging_push_database(self):
        """Test case for attach_mssql_staging_push_database

        Attaches a MSSql staging push database to a previously detached dsource.  # noqa: E501
        """
        pass

    def test_attach_oracle_dsource(self):
        """Test case for attach_oracle_dsource

        Attach an Oracle dSource to an Oracle database.  # noqa: E501
        """
        pass

    def test_create_tags_dsource(self):
        """Test case for create_tags_dsource

        Create tags for a dSource.  # noqa: E501
        """
        pass

    def test_delete_dsource(self):
        """Test case for delete_dsource

        Delete the specified dSource.  # noqa: E501
        """
        pass

    def test_delete_tags_dsource(self):
        """Test case for delete_tags_dsource

        Delete tags for a dSource.  # noqa: E501
        """
        pass

    def test_detach_mssql_database(self):
        """Test case for detach_mssql_database

        Detaches a linked source from a MSSql database.  # noqa: E501
        """
        pass

    def test_detach_oracle_dsource(self):
        """Test case for detach_oracle_dsource

        Detaches an Oracle source from an Oracle database.  # noqa: E501
        """
        pass

    def test_disable_dsource(self):
        """Test case for disable_dsource

        Disable a dSource.  # noqa: E501
        """
        pass

    def test_enable_dsource(self):
        """Test case for enable_dsource

        Enable a dSource.  # noqa: E501
        """
        pass

    def test_export_dsource_by_location(self):
        """Test case for export_dsource_by_location

        Export a dSource using timeflow location to a physical file system.  # noqa: E501
        """
        pass

    def test_export_dsource_by_snapshot(self):
        """Test case for export_dsource_by_snapshot

        Export a dSource using snapshot to a physical file system  # noqa: E501
        """
        pass

    def test_export_dsource_by_timestamp(self):
        """Test case for export_dsource_by_timestamp

        Export a dSource using timestamp to a physical file system.  # noqa: E501
        """
        pass

    def test_export_dsource_from_bookmark(self):
        """Test case for export_dsource_from_bookmark

        Export a dSource using bookmark to physical file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_bookmark(self):
        """Test case for export_dsource_to_asm_by_bookmark

        Export a dSource using bookmark to an ASM file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_location(self):
        """Test case for export_dsource_to_asm_by_location

        Export a dSource using SCN to an ASM file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_snapshot(self):
        """Test case for export_dsource_to_asm_by_snapshot

        Export a dSource by a snapshot to an ASM file system  # noqa: E501
        """
        pass

    def test_export_dsource_to_asm_by_timestamp(self):
        """Test case for export_dsource_to_asm_by_timestamp

        Export a dSource using timestamp to an ASM file system  # noqa: E501
        """
        pass

    def test_get_appdata_dsource_linking_defaults(self):
        """Test case for get_appdata_dsource_linking_defaults

        Get defaults for an AppData dSource linking.  # noqa: E501
        """
        pass

    def test_get_ase_dsource_linking_defaults(self):
        """Test case for get_ase_dsource_linking_defaults

        Get defaults for an ASE dSource linking.  # noqa: E501
        """
        pass

    def test_get_dsource_by_id(self):
        """Test case for get_dsource_by_id

        Get a dSource by ID.  # noqa: E501
        """
        pass

    def test_get_dsource_deletion_dependencies(self):
        """Test case for get_dsource_deletion_dependencies

        Get deletion dependencies for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsource_snapshots(self):
        """Test case for get_dsource_snapshots

        List Snapshots for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsources(self):
        """Test case for get_dsources

        List all dSources.  # noqa: E501
        """
        pass

    def test_get_mssql_dsource_linking_defaults(self):
        """Test case for get_mssql_dsource_linking_defaults

        Get defaults for a MSSql dSource linking.  # noqa: E501
        """
        pass

    def test_get_mssql_staging_push_dsource_linking_defaults(self):
        """Test case for get_mssql_staging_push_dsource_linking_defaults

        Get defaults for a MSSql staging push dSource linking.  # noqa: E501
        """
        pass

    def test_get_oracle_dsource_linking_defaults(self):
        """Test case for get_oracle_dsource_linking_defaults

        Get defaults for dSource linking.  # noqa: E501
        """
        pass

    def test_get_oracle_staging_push_dsource_linking_defaults(self):
        """Test case for get_oracle_staging_push_dsource_linking_defaults

        Get defaults for a Oracle staging push dSource linking.  # noqa: E501
        """
        pass

    def test_get_tags_dsource(self):
        """Test case for get_tags_dsource

        Get tags for a dSource.  # noqa: E501
        """
        pass

    def test_get_upgrade_compatible_repo_for_dsource(self):
        """Test case for get_upgrade_compatible_repo_for_dsource

        Returns a list of compatible repositories for dSource upgrade.  # noqa: E501
        """
        pass

    def test_link_appdata_database(self):
        """Test case for link_appdata_database

        Link an AppData database as dSource.  # noqa: E501
        """
        pass

    def test_link_ase_database(self):
        """Test case for link_ase_database

        Link an ASE database as dSource.  # noqa: E501
        """
        pass

    def test_link_mssql_database(self):
        """Test case for link_mssql_database

        Link a MSSql database as dSource.  # noqa: E501
        """
        pass

    def test_link_mssql_staging_push_database(self):
        """Test case for link_mssql_staging_push_database

        Link a MSSql staging push database as dSource.  # noqa: E501
        """
        pass

    def test_link_oracle_database(self):
        """Test case for link_oracle_database

        Link Oracle database as dSource.  # noqa: E501
        """
        pass

    def test_link_oracle_staging_push_database(self):
        """Test case for link_oracle_staging_push_database

        Link an Oracle staging push database as dSource.  # noqa: E501
        """
        pass

    def test_search_dsources(self):
        """Test case for search_dsources

        Search for dSources.  # noqa: E501
        """
        pass

    def test_snapshot_dsource(self):
        """Test case for snapshot_dsource

        Snapshot a dSource.  # noqa: E501
        """
        pass

    def test_update_appdata_dsource_by_id(self):
        """Test case for update_appdata_dsource_by_id

        Update values of an AppData dSource  # noqa: E501
        """
        pass

    def test_update_ase_dsource_by_id(self):
        """Test case for update_ase_dsource_by_id

        Update values of an ASE dSource  # noqa: E501
        """
        pass

    def test_update_mssql_dsource_by_id(self):
        """Test case for update_mssql_dsource_by_id

        Update values of an MSSql dSource  # noqa: E501
        """
        pass

    def test_update_oracle_dsource_by_id(self):
        """Test case for update_oracle_dsource_by_id

        Update values of an Oracle dSource  # noqa: E501
        """
        pass

    def test_upgrade_dsource(self):
        """Test case for upgrade_dsource

        Upgrade dSource  # noqa: E501
        """
        pass

    def test_upgrade_oracle_dsource(self):
        """Test case for upgrade_oracle_dsource

        Upgrade the requested Oracle dSource installation and user.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
