"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.compliance_job_collections_api import ComplianceJobCollectionsApi  # noqa: E501


class TestComplianceJobCollectionsApi(unittest.TestCase):
    """ComplianceJobCollectionsApi unit test stubs"""

    def setUp(self):
        self.api = ComplianceJobCollectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_compliance_job_collection(self):
        """Test case for create_compliance_job_collection

        Create a compliance job collection.  # noqa: E501
        """
        pass

    def test_create_compliance_job_collection_tags(self):
        """Test case for create_compliance_job_collection_tags

        Create tags for a compliance job collection.  # noqa: E501
        """
        pass

    def test_delete_compliance_job_collection(self):
        """Test case for delete_compliance_job_collection

        Delete a compliance job collection.  # noqa: E501
        """
        pass

    def test_delete_compliance_job_collection_tags(self):
        """Test case for delete_compliance_job_collection_tags

        Delete tags for a compliance job collection.  # noqa: E501
        """
        pass

    def test_execute_compliance_job_collection(self):
        """Test case for execute_compliance_job_collection

        Execute a compliance job collection.  # noqa: E501
        """
        pass

    def test_get_compliance_job_collection_by_id(self):
        """Test case for get_compliance_job_collection_by_id

        Retrieve a compliance job collection by ID.  # noqa: E501
        """
        pass

    def test_get_compliance_job_collection_jobs(self):
        """Test case for get_compliance_job_collection_jobs

        Get compliance jobs for a compliance job collection.  # noqa: E501
        """
        pass

    def test_get_compliance_job_collection_tags(self):
        """Test case for get_compliance_job_collection_tags

        Get tags for a compliance job collection.  # noqa: E501
        """
        pass

    def test_get_compliance_job_collections(self):
        """Test case for get_compliance_job_collections

        Retrieve the list of compliance job collections.  # noqa: E501
        """
        pass

    def test_search_compliance_job_collection_jobs(self):
        """Test case for search_compliance_job_collection_jobs

        Search compliance jobs for a compliance job collection.  # noqa: E501
        """
        pass

    def test_search_compliance_job_collections(self):
        """Test case for search_compliance_job_collections

        Search compliance job collections.  # noqa: E501
        """
        pass

    def test_update_compliance_job_collection(self):
        """Test case for update_compliance_job_collection

        Update a compliance job collection.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
