"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.job_collection_executions_api import JobCollectionExecutionsApi  # noqa: E501


class TestJobCollectionExecutionsApi(unittest.TestCase):
    """JobCollectionExecutionsApi unit test stubs"""

    def setUp(self):
        self.api = JobCollectionExecutionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_job_collection_execution(self):
        """Test case for cancel_job_collection_execution

        Cancel a compliance job collection execution. This operation is asynchronous is not complete until the collection execution is marked cancelled.  # noqa: E501
        """
        pass

    def test_get_job_collection_execution_by_id(self):
        """Test case for get_job_collection_execution_by_id

        Retrieve a compliance job collection execution by ID.  # noqa: E501
        """
        pass

    def test_get_job_collection_executions(self):
        """Test case for get_job_collection_executions

        Retrieve the list of compliance job collection executions.  # noqa: E501
        """
        pass

    def test_search_job_collection_executions(self):
        """Test case for search_job_collection_executions

        Search compliance job collection executions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
